==> open-xchange-oauth_7.10.4.orig.tar.bz2: open-xchange-oauth-7.10.4/com.openexchange.oauth.yahoo/src/com/openexchange/oauth/yahoo/internal/groupware/OAuthYahooDropTokensTask.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.oauth.yahoo.internal.groupware;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import com.openexchange.database.Databases;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.update.PerformParameters;
import com.openexchange.groupware.update.UpdateExceptionCodes;
import com.openexchange.groupware.update.UpdateTaskAdapter;
import com.openexchange.oauth.KnownApi;
import com.openexchange.oauth.impl.internal.groupware.OAuthCreateTableTask2;

/**
 * {@link OAuthYahooDropTokensTask}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class OAuthYahooDropTokensTask extends UpdateTaskAdapter {

    /**
     * Initialises a new {@link OAuthDropboxDropTokensTask}.
     */
    public OAuthYahooDropTokensTask() {
        super();
    }

    @Override
    public void perform(PerformParameters params) throws OXException {
        Connection writeConnection = params.getConnection();
        PreparedStatement statement = null;
        try {
            statement = writeConnection.prepareStatement("UPDATE oauthAccounts SET accessToken = ? AND accessSecret = ? WHERE serviceId = ?");

            int parameterIndex = 1;
            statement.setString(parameterIndex++, "");
            statement.setString(parameterIndex++, "");
            statement.setString(parameterIndex++, KnownApi.YAHOO.getServiceId());

            statement.execute();
        } catch (SQLException e) {
            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
        } finally {
            Databases.closeSQLStuff(statement);
        }
    }

    @Override
    public String[] getDependencies() {
        return new String[] { OAuthCreateTableTask2.class.getName() };
    }
}

==> open-xchange-oauth_7.10.5.orig.tar.bz2: open-xchange-oauth-7.10.5/com.openexchange.oauth.yahoo/src/com/openexchange/oauth/yahoo/internal/groupware/OAuthYahooDropTokensTask.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.oauth.yahoo.internal.groupware;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import com.openexchange.database.Databases;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.update.PerformParameters;
import com.openexchange.groupware.update.UpdateExceptionCodes;
import com.openexchange.groupware.update.UpdateTaskAdapter;
import com.openexchange.oauth.KnownApi;

/**
 * {@link OAuthYahooDropTokensTask}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class OAuthYahooDropTokensTask extends UpdateTaskAdapter {

    /**
     * Initialises a new {@link OAuthDropboxDropTokensTask}.
     */
    public OAuthYahooDropTokensTask() {
        super();
    }

    @Override
    public void perform(PerformParameters params) throws OXException {
        Connection writeConnection = params.getConnection();
        PreparedStatement statement = null;
        try {
            statement = writeConnection.prepareStatement("UPDATE oauthAccounts SET accessToken = ? AND accessSecret = ? WHERE serviceId = ?");

            int parameterIndex = 1;
            statement.setString(parameterIndex++, "");
            statement.setString(parameterIndex++, "");
            statement.setString(parameterIndex++, KnownApi.YAHOO.getServiceId());

            statement.execute();
        } catch (SQLException e) {
            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
        } finally {
            Databases.closeSQLStuff(statement);
        }
    }

    @Override
    public String[] getDependencies() {
        return new String[] { "com.openexchange.oauth.impl.internal.groupware.OAuthCreateTableTask2" };
    }
}
